.BG
.FN grid
.TL
Compute a design matrix for the evaluation of the
regression (or smooth) as computed by the kernel regression function
(or ppreg or nnet.predict) on the points of a 2-dimensional regular grid
.DN
Generate the design matrix from the limits and the mesh of the grid
.CS
grid(xmin, xmax, nx, ymin, ymax, ny)
.RA
.OA
.AG xmin xmax
min and max values for x
.AG nx
number of subdivisions in the x direction
.AG ymin ymax
min and max values for y
.AG ny
number of subdivisions in the y direction
.RT
Return a matrix X with (nx * ny) rows and 2 columns
    xmin                  ymin
    xmin                  ymin+(ymax-ymin)/ny
    xmin                  ymin+2(ymax-ymin)/ny
    .....                 ....................
    xmin                  ymax
    xmin+(xmax-xmin)/nx   ymin
    xmin+(xmax-xmin)/nx   ymin+(ymax-ymin)/ny
    xmin+(xmax-xmin)/nx   ymin+2(ymax-ymin)/ny
    .....                 ....................
    xmin+(xmax-xmin)/nx   ymax
    xmin+2(xmax-xmin)/nx  ymin
    xmin+2(xmax-xmin)/nx  ymin+(ymax-ymin)/ny
    .....                 ....................
    .....                 ....................
    .....                 ....................
    xmax                  ymin
    xmax                  ymin+(ymax-ymin)/ny
    xmax                  ymin+2(ymax-ymin)/ny
    .....                 ....................
    xmax                  ymax
.SA
kreg, ppreg, predict.nnet
.EX
#  If X is a nx2 matrix and Y is a nx1 vector, the command
    > XGRID <- grid(-2,2,40,-4,4,40)
    > YHAT <- kreg(X,Y,XGRID, kernel=7,b=.75)
    > YPRED <- YHAT$ypred
    > dim(YPRED) <- c(40,40)
    > persp(YPRED)
# creates a 1600x2 matrix each row containing a point of the
# regular grid of 40x40 points in the rectangle [-2,2]x[-4,4]
# compute the (Gaussian) kernel regression with bandwidth .75
# from the (training) data in X and Y, reshape the output in 
# a grid form and give a surface plot of the result over the 
# two dimensional grid.
# WARNING: the number of evaluations of the kernel regression
# can be very large and the computing time prohibitive. 
.KW 
.WR
